summaryrefslogtreecommitdiffstats
path: root/kplato/kptproject.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kplato/kptproject.cc')
-rw-r--r--kplato/kptproject.cc28
1 files changed, 14 insertions, 14 deletions
diff --git a/kplato/kptproject.cc b/kplato/kptproject.cc
index 13c44cb3..97eb8202 100644
--- a/kplato/kptproject.cc
+++ b/kplato/kptproject.cc
@@ -308,7 +308,7 @@ bool Project::load(TQDomElement &element) {
if (!s.isEmpty())
m_constraintEndTime = DateTime::fromString(s);
// Load the project tqchildren
// Must do these first
TQDomNodeList list = element.childNodes();
for (unsigned int i=0; i<list.count(); ++i) {
@@ -498,7 +498,7 @@ void Project::save(TQDomElement &element) const {
}
for (int i=0; i<numChildren(); i++)
// Save all tqchildren
getChildNode(i)->save(me);
// Now we can save relations assuming no tasks have relations outside the project
@@ -568,7 +568,7 @@ bool Project::addTask( Node* task, Node* position )
return addSubTask(task, position);
}
// find the position
// we have to tell the parent that we want to delete one of its tqchildren
Node* parentNode = position->getParent();
if ( !parentNode ) {
kdDebug()<<k_funcinfo<<"parent node not found???"<<endl;
@@ -636,7 +636,7 @@ bool Project::canIndentTask(Node* node)
//kdDebug()<<k_funcinfo<<"The root node cannot be indented"<<endl;
return false;
}
// we have to find the parent of task to manipulate its list of tqchildren
Node* parentNode = node->getParent();
if ( !parentNode ) {
return false;
@@ -679,7 +679,7 @@ bool Project::canUnindentTask( Node* node )
//kdDebug()<<k_funcinfo<<"The root node cannot be unindented"<<endl;
return false;
}
// we have to find the parent of task to manipulate its list of tqchildren
// and we need the parent's parent too
Node* parentNode = node->getParent();
if ( !parentNode ) {
@@ -714,7 +714,7 @@ bool Project::canMoveTaskUp( Node* node )
{
if (node == 0)
return false; // safety
// we have to find the parent of task to manipulate its list of tqchildren
Node* parentNode = node->getParent();
if (!parentNode) {
//kdDebug()<<k_funcinfo<<"No parent found"<<endl;
@@ -742,7 +742,7 @@ bool Project::canMoveTaskDown( Node* node )
{
if (node == 0)
return false; // safety
// we have to find the parent of task to manipulate its list of tqchildren
Node* parentNode = node->getParent();
if (!parentNode) {
return false;
@@ -779,10 +779,10 @@ Task *Project::createTask(Task &def, Node* parent) {
TQString Project::uniqueNodeId(int seed) {
int i = seed;
- while (findNode(TQString("%1").tqarg(i))) {
+ while (findNode(TQString("%1").arg(i))) {
++i;
}
- return TQString("%1").tqarg(i);
+ return TQString("%1").arg(i);
}
bool Project::removeId(const TQString &id) {
@@ -987,7 +987,7 @@ void Project::setStandardWorktime(StandardWorktime * worktime) {
}
bool Project::legalToLink(Node *par, Node *child) {
- //kdDebug()<<k_funcinfo<<par.name()<<" ("<<par.numDependParentNodes()<<" parents) "<<child.name()<<" ("<<child.numDependChildNodes()<<" tqchildren)"<<endl;
+ //kdDebug()<<k_funcinfo<<par.name()<<" ("<<par.numDependParentNodes()<<" parents) "<<child.name()<<" ("<<child.numDependChildNodes()<<" children)"<<endl;
if (!child || par->isDependChildOf(child)) {
return false;
@@ -1007,7 +1007,7 @@ bool Project::legalToLink(Node *par, Node *child) {
bool Project::legalParents(Node *par, Node *child) {
bool legal = true;
- //kdDebug()<<k_funcinfo<<par->name()<<" ("<<par->numDependParentNodes()<<" parents) "<<child->name()<<" ("<<child->numDependChildNodes()<<" tqchildren)"<<endl;
+ //kdDebug()<<k_funcinfo<<par->name()<<" ("<<par->numDependParentNodes()<<" parents) "<<child->name()<<" ("<<child->numDependChildNodes()<<" children)"<<endl;
for (int i=0; i < par->numDependParentNodes() && legal; ++i) {
Node *pNode = par->getDependParentNode(i)->parent();
if (child->isParentOf(pNode) || pNode->isParentOf(child)) {
@@ -1024,7 +1024,7 @@ bool Project::legalParents(Node *par, Node *child) {
bool Project::legalChildren(Node *par, Node *child) {
bool legal = true;
- //kdDebug()<<k_funcinfo<<par->name()<<" ("<<par->numDependParentNodes()<<" parents) "<<child->name()<<" ("<<child->numDependChildNodes()<<" tqchildren)"<<endl;
+ //kdDebug()<<k_funcinfo<<par->name()<<" ("<<par->numDependParentNodes()<<" parents) "<<child->name()<<" ("<<child->numDependChildNodes()<<" children)"<<endl;
for (int j=0; j < child->numDependChildNodes() && legal; ++j) {
Node *cNode = child->getDependChildNode(j)->child();
if (par->isParentOf(cNode) || cNode->isParentOf(par)) {
@@ -1079,7 +1079,7 @@ void Project::insertCalendarId(const TQString &id, const Calendar *calendar) {
}
#ifndef NDEBUG
-void Project::printDebug(bool tqchildren, TQCString indent) {
+void Project::printDebug(bool children, TQCString indent) {
kdDebug()<<indent<<"+ Project node: "<<name()<<endl;
indent += "!";
@@ -1087,7 +1087,7 @@ void Project::printDebug(bool tqchildren, TQCString indent) {
for ( ; it.current(); ++it)
it.current()->printDebug(indent);
- Node::printDebug(tqchildren, indent);
+ Node::printDebug(children, indent);
}
void Project::printCalendarDebug(TQCString indent) {
kdDebug()<<indent<<"-------- Calendars debug printout --------"<<endl;
@@ -308,7 +308,7 @@ bool Project::load(TQDomElement &element) {
if (!s.isEmpty())
m_constraintEndTime = DateTime::fromString(s);
- // Load the project tqchildren
+ // Load the project children
// Must do these first
TQDomNodeList list = element.childNodes();
@@ -498,7 +498,7 @@ void Project::save(TQDomElement &element) const {
}
for (int i=0; i<numChildren(); i++)
- // Save all tqchildren
+ // Save all children
getChildNode(i)->save(me);
// Now we can save relations assuming no tasks have relations outside the project
@@ -568,7 +568,7 @@ bool Project::addTask( Node* task, Node* position )
}
// find the position
- // we have to tell the parent that we want to delete one of its tqchildren
+ // we have to tell the parent that we want to delete one of its children
Node* parentNode = position->getParent();
if ( !parentNode ) {
@@ -636,7 +636,7 @@ bool Project::canIndentTask(Node* node)
return false;
}
- // we have to find the parent of task to manipulate its list of tqchildren
+ // we have to find the parent of task to manipulate its list of children
Node* parentNode = node->getParent();
if ( !parentNode ) {
@@ -679,7 +679,7 @@ bool Project::canUnindentTask( Node* node )
return false;
}
- // we have to find the parent of task to manipulate its list of tqchildren
+ // we have to find the parent of task to manipulate its list of children
// and we need the parent's parent too
Node* parentNode = node->getParent();
@@ -714,7 +714,7 @@ bool Project::canMoveTaskUp( Node* node )
if (node == 0)
return false; // safety
- // we have to find the parent of task to manipulate its list of tqchildren
+ // we have to find the parent of task to manipulate its list of children
Node* parentNode = node->getParent();
if (!parentNode) {
@@ -742,7 +742,7 @@ bool Project::canMoveTaskDown( Node* node )
if (node == 0)
return false; // safety
- // we have to find the parent of task to manipulate its list of tqchildren
+ // we have to find the parent of task to manipulate its list of children
Node* parentNode = node->getParent();
if (!parentNode) {